Index: trunk/IPs/systemC/processor/Morpheo/Behavioural/Core/Multi_Execute_loop/Execute_loop/Multi_Execute_unit/Execute_unit/Load_store_unit/SelfTest/include/Memory.h
===================================================================
--- trunk/IPs/systemC/processor/Morpheo/Behavioural/Core/Multi_Execute_loop/Execute_loop/Multi_Execute_unit/Execute_unit/Load_store_unit/SelfTest/include/Memory.h	(revision 72)
+++ trunk/IPs/systemC/processor/Morpheo/Behavioural/Core/Multi_Execute_loop/Execute_loop/Multi_Execute_unit/Execute_unit/Load_store_unit/SelfTest/include/Memory.h	(revision 75)
@@ -53,10 +53,10 @@
       }
 
-    cout << "=====[ Memory's information ]" << endl
-	 << "  * _nb_context : " << _nb_context << endl
-	 << "  * _nb_word    : " << _nb_word    << endl
-	 << "  * _size_word  : " << _size_word  << endl
-	 << "  * _shift_addr : " << _shift_addr << endl
-	 << "  * _mask_addr  : " << hex << _mask_addr << dec << endl;
+    std::cout << "=====[ Memory's information ]" << std::endl
+	      << "  * _nb_context : " << _nb_context << std::endl
+	      << "  * _nb_word    : " << _nb_word    << std::endl
+	      << "  * _size_word  : " << _size_word  << std::endl
+	      << "  * _shift_addr : " << _shift_addr << std::endl
+	      << "  * _mask_addr  : " << std::hex << _mask_addr << std::dec << std::endl;
   }
 
@@ -71,9 +71,9 @@
 						       morpheo::behavioural::Tdcache_data_t    data)
   {
-    cout << "<Memory::access>" << endl
-	 << " * context : " << context << endl
-	 << " * address : " << hex << address << dec << endl
-	 << " * type    : " << type << endl
-	 << " * wdata   : " << hex << data << dec << endl;
+    std::cout << "<Memory::access>" << std::endl
+	      << " * context : " << context << std::endl
+	      << " * address : " << std::hex << address << std::dec << std::endl
+	      << " * type    : " << type << std::endl
+	      << " * wdata   : " << std::hex << data << std::dec << std::endl;
 
     morpheo::behavioural::Tdcache_data_t rdata;
@@ -90,5 +90,5 @@
 	rdata = other (context, address, type);
 
-    cout << " * rdata   : " << hex << rdata << dec << endl;
+    std::cout << " * rdata   : " << std::hex << rdata << std::dec << std::endl;
 
     return rdata;
@@ -161,5 +161,5 @@
 						      morpheo::behavioural::Tdcache_data_t data)
   {
-    cout << "   * write" << endl;
+    std::cout << "   * write" << std::endl;
 
     if (context>_nb_context)
@@ -172,8 +172,8 @@
     morpheo::behavioural::Tdcache_address_t MSB = address >> _shift_addr;
 
-    cout << hex
-	 << "     * LSB         : " << LSB << endl
-	 << "     * MSB         : " << MSB << endl
-	 << dec;
+    std::cout << std::hex
+	 << "     * LSB         : " << LSB << std::endl
+	 << "     * MSB         : " << MSB << std::endl
+	 << std::dec;
   
     morpheo::behavioural::Tdcache_data_t data_old    = _data [context][MSB];
@@ -193,21 +193,21 @@
     uint32_t index_max = index_min+memory_size;
 
-    cout << "     * type        : " << type << endl
-	 << "     * memory_size : " << memory_size << endl
-	 << "     * index_min   : " << index_min << endl
-	 << "     * index_max   : " << index_max << endl;
+    std::cout << "     * type        : " << type << std::endl
+	 << "     * memory_size : " << memory_size << std::endl
+	 << "     * index_min   : " << index_min << std::endl
+	 << "     * index_max   : " << index_max << std::endl;
     
     morpheo::behavioural::Tdcache_data_t data_insert = data<<index_min; // the data is aligned at LSB
 
 //     cout << "read :" << endl
 // 	 << " * context     : " << context << endl
 // 	 << hex		    
 // 	 << " * address     : " << address << endl
 // 	 << "   * LSB       : " << LSB       << endl
 // 	 << "   * MSB       : " << MSB       << endl
 // 	 << dec
 // 	 << "   * index_min : " << index_min << endl
 // 	 << "   * index_max : " << index_max << endl
 // 	 << " * type        : " << type    << endl;
 
     if (index_max > _size_word)
@@ -218,8 +218,8 @@
     _data [context][MSB] = data_new;
     
-    cout << hex
-	 << "     * data_old    : " << data_old << endl
-	 << "     * data_new    : " << data_new << endl
-	 << dec;
+    std::cout << std::hex
+	      << "     * data_old    : " << data_old << std::endl
+	      << "     * data_new    : " << data_new << std::endl
+	      << std::dec;
 
 
@@ -277,9 +277,9 @@
 	  }
 	std::cout << " - "
-		  << hex
+		  << std::hex
 		  << i->_address << " : "
 		  << i->_data_old << " -> "
 		  << i->_data_new << std::endl
-		  << hex;
+		  << std::hex;
       }
   }
@@ -193,21 +193,21 @@
     morpheo::behavioural::Tdcache_data_t data_insert = data<<index_min; // the data is aligned at LSB
 
-//     cout << "read :" << endl
-// 	 << " * context     : " << context << endl
-// 	 << hex		    
-// 	 << " * address     : " << address << endl
-// 	 << "   * LSB       : " << LSB       << endl
-// 	 << "   * MSB       : " << MSB       << endl
-// 	 << dec
-// 	 << "   * index_min : " << index_min << endl
-// 	 << "   * index_max : " << index_max << endl
-// 	 << " * type        : " << type    << endl;
+//     std::cout << "read :" << std::endl
+// 	 << " * context     : " << context << std::endl
+// 	 << std::hex		    
+// 	 << " * address     : " << address << std::endl
+// 	 << "   * LSB       : " << LSB       << std::endl
+// 	 << "   * MSB       : " << MSB       << std::endl
+// 	 << std::dec
+// 	 << "   * index_min : " << index_min << std::endl
+// 	 << "   * index_max : " << index_max << std::endl
+// 	 << " * type        : " << type    << std::endl;
 
     if (index_max > _size_word)
